@@ -33,13 +33,15 @@ Please, note that the following packages should be installed before using this p
 
 __VERSION__ = 1.0
 
+#from sys import path 
+#path.append('./mu32')
 
 import numpy as np
 from ctypes import addressof, byref, sizeof, create_string_buffer, CFUNCTYPE
 from math import ceil as ceil
 
 from mu32.log import logging, mulog as log, mu32log						# mu32log for backward compatibility
-from mu32.exception import Mu32Exception
+from mu32.exception import Mu32Exception, MuException
 from mu32.core_base import MegaMicro, MU32_SYSTEM_NAME, MU32USB2_SYSTEM_NAME, MU256_SYSTEM_NAME, MU1024_SYSTEM_NAME
 from mu32.core_ws import MegaMicroWS
 
