@@ -41,7 +41,7 @@ import usb1
 import time
 import numpy as np
 import queue
-import json
+import cv2 as cv
 from datetime import datetime
 from ctypes import addressof, byref, sizeof, create_string_buffer, CFUNCTYPE
 from math import ceil as ceil
@@ -143,6 +143,20 @@ DEFAULT_H5_COMPRESSION_ALGO 		= 'gzip'								# Compression algorithm (gzip, lzf
 DEFAULT_H5_GZIP_LEVEL 				= 4										# compression level for gzip algo (0 to 9, default 4) 
 DEFAULT_H5_DIRECTORY				= './'									# The default directory where H5 files are saved
 
+"""
+Default video monitoring values
+"""
+DEFAULT_CV_MONITORING				= False									# Whether video monitoring is On or Off
+DEFAULT_CV_CODEC					= 'mp4v'								# Video codec (OS/platform dependant)
+DEFAULT_CV_DEVICE					= 0										# Default camera device (0, 1, 2,... depending on connected devices)
+DEFAULT_CV_DIRECTORY				= './'									# The default directory where video files are saved
+DEFAULT_CV_COLOR_MODE				= cv.COLOR_BGR2GRAY						# Default set to grey frames
+DEFAULT_CV_SAMPLING_FREQUENCY		= 20.0									# Frame number per seconds
+DEFAULT_CV_SHOW						= False									# Whether frames are showed or not 
+DEFAULT_CV_WIDTH					= 640									# Frame size (width)
+DEFAULT_CV_HEIGHT					= 480									# Frame size (height)
+DEFAULT_CV_FILE_DURATION			= 15*60									# Time duration of a complete Video file in seconds
+
 class MegaMicro:
 	"""
 	MegaMicro core abstract class
@@ -158,6 +172,7 @@ class MegaMicro:
 	_available_mems = None
 	_analogs = DEFAULT_ACTIVATED_ANALOG
 	_analogs_number = len( _analogs )
+	_available_analogs = None
 	_counter = DEFAULT_ACTIVATED_COUNTER
 	_counter_skip = DEFAULT_COUNTER_SKIPPING
 	_status = DEFAULT_ACTIVATED_STATUS
@@ -197,7 +212,18 @@ class MegaMicro:
 	_h5_buffer_length = _h5_dataset_length
 	_h5_buffer_index = 0
 	_h5_timestamp = 0
+	_cv_monitoring = DEFAULT_CV_MONITORING
+	_cv_codec = DEFAULT_CV_CODEC
+	_cv_device = DEFAULT_CV_DEVICE
+	_cv_rootdir = DEFAULT_CV_DIRECTORY
+	_cv_color_mode = DEFAULT_CV_COLOR_MODE
+	_cv_sampling_frequency = DEFAULT_CV_SAMPLING_FREQUENCY
+	_cv_show = DEFAULT_CV_SHOW
+	_cv_file_duration = DEFAULT_CV_FILE_DURATION
 
+	__cv_thread = None
+	__cv_thread_exception: MuException = None
+	__cv_running = False
 
 	def __init__( self, usb_vendor_id, usb_vendor_product, usb_bus_address, pluggable_beams_number ):
 		"""
@@ -320,7 +346,15 @@ class MegaMicro:
 			'h5_file_duration': self._h5_file_duration,
 			'h5_compressing': self._h5_compressing,
 			'h5_compression_algo': self._h5_compression_algo,
-			'h5_gzip_level': self._h5_gzip_level
+			'h5_gzip_level': self._h5_gzip_level,
+			'cv_monitoring':self._cv_monitoring,
+			'cv_codec': self._cv_codec,
+			'cv_device': self._cv_device,
+			'cv_rootdir': self._cv_rootdir,
+			'cv_color_mode': self._cv_color_mode,
+			'cv_sampling_frequency': self._cv_sampling_frequency,
+			'cv_show': self._cv_show,
+			'cv_file_duration': self._cv_file_duration
 		}
 
 	@property
@@ -350,7 +384,15 @@ class MegaMicro:
 			'h5_file_duration': self._h5_file_duration,
 			'h5_compressing': self._h5_compressing,
 			'h5_compression_algo': self._h5_compression_algo,
-			'h5_gzip_level': self._h5_gzip_level
+			'h5_gzip_level': self._h5_gzip_level,
+			'cv_monitoring':self._cv_monitoring,
+			'cv_codec': self._cv_codec,
+			'cv_device': self._cv_device,
+			'cv_rootdir': self._cv_rootdir,
+			'cv_color_mode': self._cv_color_mode,
+			'cv_sampling_frequency': self._cv_sampling_frequency,
+			'cv_show': self._cv_show,
+			'cv_file_duration': self._cv_file_duration
 		}
 
 	@property
@@ -935,6 +977,7 @@ class MegaMicro:
 		block = DEFAULT_BLOCK_FLAG
 		callback_fn = None
 		post_callback_fn = None
+
 		h5_recording = DEFAULT_H5_RECORDING
 		h5_rootdir = DEFAULT_H5_DIRECTORY
 		h5_dataset_duration = DEFAULT_H5_SEQUENCE_DURATION
@@ -943,6 +986,15 @@ class MegaMicro:
 		h5_compression_algo = DEFAULT_H5_COMPRESSION_ALGO
 		h5_gzip_level = DEFAULT_H5_GZIP_LEVEL
 
+		cv_monitoring = DEFAULT_CV_MONITORING
+		cv_codec = DEFAULT_CV_CODEC
+		cv_device = DEFAULT_CV_DEVICE
+		cv_rootdir = DEFAULT_CV_DIRECTORY
+		cv_color_mode = DEFAULT_CV_COLOR_MODE
+		cv_sampling_frequency = DEFAULT_CV_SAMPLING_FREQUENCY
+		cv_show = DEFAULT_CV_SHOW
+		cv_file_duration = DEFAULT_CV_FILE_DURATION
+
 		if len( kwargs ) == 0:
 			"""
 			No argument provided -> perform autotest
@@ -978,6 +1030,7 @@ class MegaMicro:
 				status = parameters.get( 'status' )			
 			if 'block' in parameters:
 				block = parameters.get( 'block' )
+
 			if 'h5_recording' in parameters:
 				h5_recording = parameters.get( 'h5_recording' )
 			if 'h5_rootdir' in parameters:
@@ -992,7 +1045,25 @@ class MegaMicro:
 				h5_compression_algo = parameters.get( 'h5_compression_algo' )	
 			if 'h5_gzip_level' in parameters:
 				h5_gzip_level = parameters.get( 'h5_gzip_level' )
-		
+
+			if 'cv_monitoring' in parameters:
+				cv_monitoring = parameters.get( 'cv_monitoring' )				
+			if 'cv_codec' in parameters:
+				cv_codec = parameters.get( 'cv_codec' )				
+			if 'cv_device' in parameters:
+				cv_device = parameters.get( 'cv_device' )				
+			if 'cv_rootdir' in parameters:
+				cv_rootdir = parameters.get( 'cv_rootdir' )				
+			if 'cv_color_mode' in parameters:
+				cv_color_mode = parameters.get( 'cv_color_mode' )				
+			if 'cv_sampling_frequency' in parameters:
+				cv_sampling_frequency = parameters.get( 'cv_sampling_frequency' )
+			if 'cv_show' in parameters:
+				cv_show = parameters.get( 'cv_show' )
+			if 'cv_file_duration' in parameters:
+				cv_file_duration = parameters.get( 'cv_file_duration' )
+
+
 		"""
 		Update with run() arguments
 		"""
@@ -1009,6 +1080,7 @@ class MegaMicro:
 		if 'post_callback_fn' in kwargs: post_callback_fn = kwargs['post_callback_fn']
 		if 'callback_fn' in kwargs: callback_fn = kwargs['callback_fn']
 		if 'block' in kwargs: block = kwargs['block']
+
 		if 'h5_recording' in kwargs: h5_recording = kwargs['h5_recording']
 		if 'h5_rootdir' in kwargs: h5_rootdir = kwargs['h5_rootdir']
 		if 'h5_dataset_duration' in kwargs: h5_dataset_duration = kwargs['h5_dataset_duration']
@@ -1017,6 +1089,16 @@ class MegaMicro:
 		if 'h5_compression_algo' in kwargs: h5_compression_algo = kwargs['h5_compression_algo']
 		if 'h5_gzip_level' in kwargs: h5_gzip_level = kwargs['h5_gzip_level']
 
+		if 'cv_monitoring' in kwargs: cv_monitoring = kwargs['cv_monitoring']
+		if 'cv_codec' in kwargs: cv_codec = kwargs['cv_codec']
+		if 'cv_device' in kwargs: cv_device = kwargs['cv_device']
+		if 'cv_rootdir' in kwargs: cv_directory = kwargs['cv_rootdir']
+		if 'cv_color_mode' in kwargs: cv_color_mode = kwargs['cv_color_mode']
+		if 'cv_sampling_frequency' in kwargs: cv_sampling_frequency = kwargs['cv_sampling_frequency']
+		if 'cv_show' in kwargs: cv_show = kwargs['cv_show']
+		if 'cv_file_duration' in kwargs: cv_file_duration = kwargs['cv_file_duration']
+
+
 		"""
 		Set atributes
 		"""
@@ -1040,6 +1122,7 @@ class MegaMicro:
 		self._post_callback_fn = post_callback_fn
 		self._callback_fn = callback_fn
 		self._block = block
+
 		self._h5_recording = h5_recording
 		self._h5_rootdir = h5_rootdir
 		self._h5_dataset_duration = h5_dataset_duration
@@ -1049,181 +1132,14 @@ class MegaMicro:
 		self._h5_compression_algo = h5_compression_algo
 		self._h5_gzip_level = h5_gzip_level
 
-
-	def run_setargs_old( self, kwargs ):
-		"""
-		Set MegaMicro property values according default, input arguments end/or parameter list given as argument 
-
-		* clockdiv decide for the sampling frequency. The sampling frequency is given by int( 500000/( clockdiv+1 ) ).Ex: 0x09 set for 50kHz
-		* buffers_number is the number of buffers used by the USB device for the data bulk transfer. It can be set from 1 to n>1 (default is given by MU_DEFAULT_BUFFERS_NUMBER).
-		* buffer_length is the number of samples that will be sent for each microphone by the Mu32 system in each transfer buffer. buffers_number_number and buffer_length have effects on latence and real time capabilities. 
-		* duration is the desired recording time in seconds
-
-		Setting buffers_number to 1 should be used only for autotest purpose since it cannot ensure real time processing.
-		The more buffers_number is the more real time can be ensured without timeout or data flow breaks problems.
-		Conversely latency is increased.
-		"""
-
-		if kwargs.get('sampling_frequency') is None: sampling_frequency=DEFAULT_SAMPLING_FREQUENCY
-		else: sampling_frequency=kwargs.get('sampling_frequency')
-		if kwargs.get('buffers_number') is None: buffers_number=DEFAULT_BUFFERS_NUMBER
-		else: buffers_number=kwargs.get('buffers_number')
-		if kwargs.get('buffer_length') is None: buffer_length=DEFAULT_BUFFER_LENGTH
-		else: buffer_length=kwargs.get('buffer_length')
-		if kwargs.get('duration') is None: duration=DEFAULT_DURATION
-		else: duration=kwargs.get('duration')
-		if kwargs.get('datatype') is None: datatype=DEFAULT_DATATYPE
-		else: datatype=kwargs.get('datatype')
-		if kwargs.get('mems') is None: mems=DEFAULT_ACTIVATED_MEMS
-		else: mems=kwargs.get('mems')
-		if kwargs.get('analogs') is None: analogs=DEFAULT_ACTIVATED_ANALOG
-		else: analogs=kwargs.get('analogs')
-		if kwargs.get('counter') is None: counter=DEFAULT_ACTIVATED_COUNTER
-		else: counter=kwargs.get('counter')
-		if kwargs.get('counter_skip') is None: counter_skip=DEFAULT_COUNTER_SKIPPING
-		else: counter_skip=kwargs.get('counter_skip')
-		if kwargs.get('status') is None: status=DEFAULT_ACTIVATED_STATUS
-		else: status=kwargs.get('status')
-		if kwargs.get('post_callback_fn') is None: post_callback_fn=None
-		else: post_callback_fn=kwargs.get('post_callback_fn')
-		if kwargs.get('callback_fn') is None: callback_fn=None
-		else: callback_fn=kwargs.get('callback_fn')
-		if kwargs.get('block') is None: block=DEFAULT_BLOCK_FLAG
-		else: block=kwargs.get('block')
-		if kwargs.get('parameters') is None: parameters=None
-		else: parameters=kwargs.get('parameters')
-		if kwargs.get('h5_recording') is None: h5_recording=DEFAULT_H5_RECORDING
-		else: h5_recording=kwargs.get('h5_recording')
-		if kwargs.get('h5_rootdir') is None: h5_rootdir=DEFAULT_H5_DIRECTORY
-		else: h5_rootdir=kwargs.get('h5_rootdir')
-		if kwargs.get('h5_dataset_duration') is None: h5_dataset_duration=DEFAULT_H5_SEQUENCE_DURATION
-		else: h5_dataset_duration=kwargs.get('h5_dataset_duration')
-		if kwargs.get('h5_file_duration') is None: h5_file_duration=DEFAULT_H5_FILE_DURATION
-		else: h5_file_duration=kwargs.get('h5_file_duration')
-		if kwargs.get('h5_compressing') is None: h5_compressing=DEFAULT_H5_COMPRESSING
-		else: h5_compressing=kwargs.get('h5_compressing')
-		if kwargs.get('h5_compression_algo') is None: h5_compression_algo=DEFAULT_H5_COMPRESSION_ALGO
-		else: h5_compression_algo=kwargs.get('h5_compression_algo')
-		if kwargs.get('h5_gzip_level') is None: h5_gzip_level=DEFAULT_H5_GZIP_LEVEL
-		else: h5_gzip_level=kwargs.get('h5_gzip_level')
-
-		if len( kwargs ) == 0:
-			"""
-			No argument provided -> perform autotest
-			"""
-			post_callback_fn = self.autotest
-			mems = [i for i in range( self._pluggable_beams_number*MU_BEAM_MEMS_NUMBER )]
-
-
-		if parameters is not None:
-			"""
-			set default values
-			"""
-			sampling_frequency = DEFAULT_SAMPLING_FREQUENCY
-			buffers_number = DEFAULT_BUFFERS_NUMBER
-			buffer_length = DEFAULT_BUFFER_LENGTH
-			duration = DEFAULT_DURATION
-			datatype = DEFAULT_DATATYPE
-			mems = DEFAULT_ACTIVATED_MEMS
-			analogs = DEFAULT_ACTIVATED_ANALOG
-			counter = DEFAULT_ACTIVATED_COUNTER
-			counter_skip = DEFAULT_COUNTER_SKIPPING
-			status = DEFAULT_ACTIVATED_STATUS
-			block = DEFAULT_BLOCK_FLAG
-			h5_recording = DEFAULT_H5_RECORDING
-			h5_rootdir = DEFAULT_H5_DIRECTORY
-			h5_dataset_duration = DEFAULT_H5_SEQUENCE_DURATION
-			h5_file_duration = DEFAULT_H5_FILE_DURATION
-			h5_compressing = DEFAULT_H5_COMPRESSING
-			h5_compression_algo = DEFAULT_H5_COMPRESSION_ALGO
-			h5_gzip_level = DEFAULT_H5_GZIP_LEVEL
-
-			"""
-			update with parameters dictionnary content 
-			"""
-			if 'sampling_frequency' in parameters:
-				sampling_frequency = parameters.get( 'sampling_frequency' )
-			if 'buffers_number' in parameters:
-				buffers_number = parameters.get( 'buffers_number' )
-			if 'buffer_length' in parameters:
-				buffer_length = parameters.get( 'buffer_length' )
-			if 'duration' in parameters:
-				duration = parameters.get( 'duration' )
-			if 'datatype' in parameters:
-				datatype = parameters.get( 'datatype' )
-			if 'mems' in parameters:
-				mems = parameters.get( 'mems' )
-			if 'analogs' in parameters:
-				analogs = parameters.get( 'analogs' )
-			if 'counter' in parameters:
-				counter = parameters.get( 'counter' )		
-			if 'counter_skip' in parameters:
-				counter_skip = parameters.get( 'counter_skip' )		
-			if 'status' in parameters:
-				status = parameters.get( 'status' )			
-			if 'block' in parameters:
-				block = parameters.get( 'block' )
-			if 'h5_recording' in parameters:
-				h5_recording = parameters.get( 'h5_recording' )
-			if 'h5_rootdir' in parameters:
-				h5_rootdir = parameters.get( 'h5_rootdir' )	
-			if 'h5_seq_duration' in parameters:
-				h5_dataset_duration = parameters.get( 'h5_dataset_duration' )
-			if 'h5_file_duration' in parameters:
-				h5_file_duration = parameters.get( 'h5_file_duration' )	
-			if 'h5_compressing' in parameters:
-				h5_compressing = parameters.get( 'h5_compressing' )	
-			if 'h5_compression_algo' in parameters:
-				h5_compression_algo = parameters.get( 'h5_compression_algo' )	
-			if 'h5_gzip_level' in parameters:
-				h5_gzip_level = parameters.get( 'h5_gzip_level' )	
-
-		self._clockdiv = max( int( 500000 / sampling_frequency ) - 1, 9 )
-		self._sampling_frequency = 500000 / ( self._clockdiv + 1 )
-		self._buffer_length = buffer_length
-		self._buffers_number = buffers_number
-		self._datatype = datatype
-		self._buffer_duration = self._buffer_length / self._sampling_frequency
-		self._duration = duration
-		self._mems = mems
-		self._mems_number = len( self._mems )
-		self._analogs = analogs
-		self._analogs_number = len( self._analogs )
-		self._counter = counter
-		self._counter_skip = counter_skip
-		self._status = status
-		self._channels_number = self._mems_number + self._analogs_number + self._counter + self._status
-		self._buffer_words_length = self._channels_number*self._buffer_length
-		self._transfers_count = int( ( self._duration * self._sampling_frequency ) // self._buffer_length )
-		self._post_callback_fn = post_callback_fn
-		self._callback_fn = callback_fn
-		self._block = block
-		self._h5_recording = h5_recording
-		self._h5_rootdir = h5_rootdir
-		self._h5_dataset_duration = h5_dataset_duration
-		self._h5_file_duration = h5_file_duration
-		self._h5_dataset_number = int( h5_file_duration // h5_dataset_duration )
-		self._h5_compressing = h5_compressing
-		self._h5_compression_algo = h5_compression_algo
-		self._h5_gzip_level = h5_gzip_level
-
-		"""
-		Do some controls
-		"""
-		if self._datatype != 'int32' and self._datatype != 'float32':
-			log.warming( f"Unknown datatype [{self._datatype}]. Set to int32" )
-			self._datatype = 'int32'
-
-		if sampling_frequency > 50000:
-			log.warning( f"Desired sampling frequency [{self._sampling_frequency} Hz] is greater than the max admissible sampling frequency. Adjusted to 50kHz" )
-			self._sampling_frequency = 50000
-
-		if self._counter_skip and not self._counter:
-			log.warning( 'Cannot skip counter in the absence of counter (counter flag is off)' )
-
-		if not os.path.exists( self._h5_rootdir ):
-			log.warning( f"No H5 path `{self._h5_rootdir}` found in file system. Adjust to default" )
-			self._h5_rootdir = DEFAULT_H5_DIRECTORY
+		self._cv_monitoring = cv_monitoring
+		self._cv_codec = cv_codec
+		self._cv_device = cv_device
+		self._cv_rootdir = cv_rootdir
+		self._cv_color_mode = cv_color_mode
+		self._cv_sampling_frequency = cv_sampling_frequency
+		self._cv_show = cv_show
+		self._cv_file_duration = cv_file_duration
 
 
 	def run( self, **kwargs ):
@@ -1261,6 +1177,17 @@ class MegaMicro:
 			if self._counter_skip and not self._counter:
 				log.warning( 'Mu32: cannot skip counter in the absence of counter (counter flag is off)' )
 
+			if self._cv_monitoring:
+				"""
+				Start video monitoring if requested
+				"""
+				log.info( f" .Video monitoring: ON" )
+				self.__cv_running = True
+				self.__cv_thread = threading.Thread( target = self.cv_monitor_loop )
+				self.__cv_thread.start()
+			else:
+				log.info( f" .Video monitoring: OFF" )
+
 			if self._block:
 				self.transfer_loop()
 			else: 
@@ -1287,6 +1214,12 @@ class MegaMicro:
 		if self._transfer_thread_exception:
 			raise self._transfer_thread_exception
 
+		if self._cv_monitoring:
+			self.__cv_running = False
+			self.__cv_thread.join()
+			if self.__cv_thread_exception:
+				raise self.__cv_thread_exception
+
 
 	def is_alive( self ):
 		"""
@@ -1305,6 +1238,110 @@ class MegaMicro:
 		"""
 		self._recording = False
 
+		"""
+		Stop monitoring if any
+		"""
+		if self._cv_monitoring:
+			self.__cv_running = False
+
+	def cv_monitor_loop( self ):
+
+		log.info( f" .Starting video monitoring thread..." )
+
+		"""
+		Set filename
+		"""
+		date = datetime.now()
+		timestamp0 = date.timestamp()
+		date0str = datetime.strftime(date, '%Y-%m-%d %H:%M:%S.%f')
+		abs_path = os.path.abspath( self._cv_rootdir )
+		filename = os.path.join( abs_path, 'muVideo-' + f"{date.year}{date.month:02}{date.day:02}-{date.hour:02}{date.minute:02}{date.second:02}" + '.mp4' )
+
+		"""
+		Init video
+		"""
+		try:
+			self.cv_log_info()
+
+			cap = cv.VideoCapture( self._cv_device )
+			if not cap.isOpened():
+				raise MuException( f"Video camera initialization failed" )
+
+			width = int( cap.get( cv.CAP_PROP_FRAME_WIDTH ) )
+			height = int( cap.get( cv.CAP_PROP_FRAME_HEIGHT ) )
+			log.info( f" .Video frame size: {width} x {height} pixels" )
+
+			fourcc = cv.VideoWriter_fourcc( *self._cv_codec )   # .mp4
+			log.info( f" .Video codec: {self._cv_codec}" )
+
+			file_frame_nbr = int( self._cv_sampling_frequency * self._cv_file_duration )
+			log.info( f" .Video file frames number: {file_frame_nbr}" )
+
+			out = cv.VideoWriter( filename, fourcc, self._cv_sampling_frequency, (width,  height), isColor=False )
+			log.info( f" .Video create new file: {filename}" )
+
+
+		except Exception as e:
+			self.__cv_thread_exception = MuException( f"Video thread failed during initialization: {e}" )
+			log.info( f" .Exiting from monitoring thread on error: {e}" )
+			return
+
+		"""
+		Start loop
+		"""
+		try:
+			frame_number = 0
+			while self.__cv_running and cap.isOpened():
+				ret, frame = cap.read()
+				if not ret:
+					raise MuException( f"Can't receive video frame (stream end?). Exiting ..." )
+				frame = cv.cvtColor(frame, cv.COLOR_BGR2GRAY)
+				if frame_number >= file_frame_nbr:
+					"""
+					Open a new file
+					"""
+					out.release()
+					date = datetime.now()
+					abs_path = os.path.abspath( self._cv_rootdir )
+					filename = os.path.join( abs_path, 'muVideo-' + f"{date.year}{date.month:02}{date.day:02}-{date.hour:02}{date.minute:02}{date.second:02}" + '.mp4' )
+					out = cv.VideoWriter( filename, fourcc, self._cv_sampling_frequency, (width,  height), isColor=False )
+					log.info( f" .Video create new file: {filename}" )
+					frame_number = 0
+
+				out.write( frame )
+				if self._cv_show:
+					cv.imshow( 'frame', frame )
+				frame_number += 1
+
+		except Exception as e:
+			self.__cv_thread_exception = MuException( f"Video thread failed during monitoring loop: {e}" )
+			cap.release()
+			out.release()
+			cv.destroyAllWindows()
+			log.info( f" .Exiting from monitoring thread on error: {e}" )
+			return
+
+		"""
+		Job is finished -> release everything
+		"""
+		cap.release()
+		out.release()
+		cv.destroyAllWindows()
+		log.info( f" .Video monitoring thread stopped" )
+
+
+	def cv_log_info( self ):
+		"""
+		Log requested parameter values about video monitoring
+		"""
+		log.info( f" .Video codec: {self._cv_codec}" )
+		log.info( f" .Video device: {self._cv_device}" )
+		log.info( f" .Video recording directory: {self._cv_rootdir}" )
+		log.info( f" .Video colormode is: {self._cv_color_mode}" )
+		log.info( f" .Video frame frequency: {self._cv_sampling_frequency}" )
+		log.info( f" .Video showing video stream: {self._cv_show}" )
+		log.info( f" .Video files duration: {self._cv_file_duration}s" )
+
 
 	def transfer_loop( self ):
 
