@@ -262,7 +262,9 @@ class MuH5( MegaMicro ):
 			Perform controls on requested parameter values: see if they are in accordance with H5 file parameters
 			"""
 			if self._sampling_frequency != self._h5_parameters['sampling_frequency']:
-				raise MuException( f"MuH5: no available under/over sampling algorithm: requested sampling frequency of {self._sampling_frequency}Hz do not match recording one at {self._h5_parameters['sampling_frequency']}Hz" )
+				log.warning( f"Requested sampling frequency of {self._sampling_frequency}Hz does not match recording one at {self._h5_parameters['sampling_frequency']}Hz: force to {self._h5_parameters['sampling_frequency']}Hz" )
+				self._sampling_frequency = self._h5_parameters['sampling_frequency']
+				#raise MuException( f"MuH5: no available under/over sampling algorithm: requested sampling frequency of {self._sampling_frequency}Hz do not match recording one at {self._h5_parameters['sampling_frequency']}Hz" )
 
 			if self._counter and not self._counter_skip and ( not self._h5_parameters['counter'] or ( self._h5_parameters['counter'] and self._h5_parameters['counter_skip'] ) ):
 				raise MuException( f"MuH5: Counter is requested but not available on H5 data" )
@@ -287,6 +289,25 @@ class MuH5( MegaMicro ):
 				"""
 				raise MuException( f"Some activated microphones ({activated_mems[mask]}) are not available on H5 file {self._h5_current_filename}. Available MEMs are: {self._h5_parameters['mems']} ")
 
+			if 'analogs' in self._h5_parameters:
+				self._available_analogs = list( self._h5_parameters['analogs'] )
+				activated_analogs = np.array( self._analogs )
+				mask_analogs = np.logical_not( np.isin( activated_analogs , self._h5_parameters['analogs'] ) )
+				if len( activated_analogs[mask_analogs] ) > 0:
+					"""
+					Some activated analog channels are not available in the H5 file -> abort
+					Abort for same reasons as for MEMs.
+					"""
+					raise MuException( f"Some activated analogics ({activated_analogs[mask_analogs]}) are not available on H5 file {self._h5_current_filename}. Available analogs channels are: {self._h5_parameters['analogs']} ")
+			else:
+				self._available_analogs = None
+				if len( self._analogs ) > 0:
+					"""
+					Analog channels are not available in the H5 file but some are selected -> abort
+					Abort for same reasons as for MEMs.
+					"""
+					raise MuException( f"There are no analogics channels avalable on H5 file {self._h5_current_filename}. Please do not select them (selected are: {self._analogs})")
+
 
 			"""
 			Start playing
@@ -294,13 +315,14 @@ class MuH5( MegaMicro ):
 			log.info( f" .Reading H5 file {self._h5_current_filename}")
 			log.info( f" .{self._h5_parameters['duration']}s ({(self._h5_parameters['duration']/60):.02}min) of data in {self._h5_current_filename} H5 file" )
 			log.info( f" .starting time: {self._h5_start_time}s" )
-			log.info( f" .Available mems: {self._available_mems}" )
+			log.info( f" .available mems: {self._available_mems}" )
 			log.info( f" .whether counter available: {self._h5_parameters['counter'] and not self._h5_parameters['counter_skip']}" )
 			log.info( f" .desired recording duration: {self._duration} s" )
 			log.info( f" .minimal recording duration: {( self._transfers_count*self._buffer_length ) / self._sampling_frequency} s" )
 			log.info( f" .{self._mems_number} activated microphones" )
 			log.info( f" .activated microphones: {self._mems}" )
 			log.info( f" .{self._analogs_number} activated analogic channels" )
+			log.info( f" .available analogic channels: {self._available_analogs}" )
 			log.info( f" .activated analogic channels: {self._analogs }" )
 			log.info( f" .whether counter is activated: {self._counter}" )
 			log.info( f" .whether status is activated: {self._status}" )
@@ -345,10 +367,10 @@ class MuH5( MegaMicro ):
 			dataset = self._h5_current_file['muh5/' + str( self._h5_dataset_index ) + '/sig']
 
 			"""
-			Set the mask for mems selecting
-			* mask: the binary mask for slecting channels to get
+			Set the mask for mems and analogs selecting
+			* mask: the binary mask for selecting channels to get
 			* masking: True if somme channels are masked, False for complete copy
-			* channels_number: selected microphones + counter if available and selected
+			* channels_number: selected microphones + counter if available and selected + selected analogs
 			"""
 			mask = list( np.isin( self._available_mems, self._mems ) )
 			if self._h5_parameters['counter'] and not self._h5_parameters['counter_skip']:
@@ -362,6 +384,10 @@ class MuH5( MegaMicro ):
 					mask = [False] + mask
 				else:
 					mask = [True] + mask
+
+			if self._available_analogs != None:
+				mask = mask + list( np.isin( self._available_analogs, self._analogs ) )
+
 			channels_number = sum(mask)
 			masking = channels_number != len(mask)
 
