@@ -28,6 +28,9 @@ The mu32.core_server module defines a server for using MegaMico receiver through
 * See documentation on websockets https://websockets.readthedocs.io
 * For full real time server example see:  https://jackylishi.medium.com/build-a-realtime-dash-app-with-websockets-5d25fa627c7a
 * Also see: https://www.programcreek.com/python/example/94580/websockets.serve
+* MegaMicro usb device is not mounted after boot on JetsonNano devices. We have to unplug then replug it
+* For that problem: see https://www.infineon.com/cms/en/design-support/tools/configuration/usb-ez-usb-sx3-configuration-utility/?utm_source=cypress&utm_medium=referral&utm_campaign=202110_globe_en_all_integration-software)
+
 
 Please, note that the following packages should be installed before using this program:
 
@@ -42,10 +45,12 @@ To do:
 """
 
 
+from ast import Bytes
 import asyncio
 import fnmatch
 from os import path, listdir, getcwd
 from ctypes import sizeof
+import threading
 from time import sleep, time_ns
 from datetime import datetime
 from threading import Timer, BoundedSemaphore
@@ -65,6 +70,9 @@ DEFAULT_HOST = "127.0.0.1"
 DEFAULT_PORT = 8002
 DEFAULT_MEGAMICRO_SYSTEM = 'Mu32'
 DEFAULT_MAX_CONNECTIONS = 5
+DEFAULT_FILESENDING_BUFFER_SIZE = 1024
+DEFAULT_CONFIG_PATH = './megamicro.json'
+DEFAULT_MAX_ERROR_SCHED_COUNTER = 10
 SRV_MEGAMICRO_MAX_RUN = 1
 SRV_SCHEDULER_LIST_MAXSIZE = 100
 
@@ -76,6 +84,7 @@ under certain conditions; see the source code for details.\n' + '-'*20
 
 #log.setLevel( logging.INFO )
 
+
 class MegaMicroServer():
     """
     Server for sharing a megamicro receiver among multiple remote users.
@@ -95,16 +104,25 @@ class MegaMicroServer():
     _parameters = {}
     _status = {}
     _svc_counter = 0
-    _h5_filename = None
+    _filename = None
     _megamicro_sem = None
-    _h5_rootdir = './'
+    _h5_rootdir = None
+    _config_path = DEFAULT_CONFIG_PATH
+    _config = {}
 
 
-    def __init__( self, maxconnect=DEFAULT_MAX_CONNECTIONS, filename=None ):
+    def __init__( self, maxconnect=DEFAULT_MAX_CONNECTIONS, filename=None, config_path=DEFAULT_CONFIG_PATH ):
+        """
+        Init server
+        :param maxconnect: Optionnel. Max client simultaneous allowed connections (default is 5)
+        :type maxconnect: int
+        :param filename: Optionnal. File name or directory path where to look at H5 file for playing them. Default is None
+        :type filename: str
+        :param config_path: Optionnal. Path of the configuration file. Default is ./megamicro.conf in current directory
+        :type config_path: str
+        :raise MuException: if no available H5 root diurectory
+        """
 
-        self._maxconnect = maxconnect
-        self._megamicro_sem = BoundedSemaphore( value=SRV_MEGAMICRO_MAX_RUN )
-        self._h5_filename = filename
         self._status = {
             'start_time': time_ns(),
             'error': False,
@@ -112,13 +130,70 @@ class MegaMicroServer():
             'last_control_time': 0,
             'parameters': {}
         }
-        
+        log.info( f"Starting MegaMicro server at {datetime.fromtimestamp(self._status['start_time']//10**9)}" )
+
+        """
+        Get the config file values if any
+        """
+        self._config_path, self._config = self._get_config( config_path )
+
+        if 'maxconnect' in self._config and self._config['maxconnect'] != maxconnect:
+            self._maxconnect = self._config['maxconnect']
+        else:
+            self._maxconnect = maxconnect
+
+        if 'filename' in self._config and self._config['filename'] != filename:
+            self._filename = self._config['filename']
+        else:
+            self._filename = filename
+       
         """
         Set H5 root directory to current working directory
         """
-        self._h5_rootdir = getcwd()
+        h5_rootdir = getcwd()
+        if 'h5_rootdir' in self._config and self._config['h5_rootdir'] != h5_rootdir:
+            self._h5_rootdir = self._config['h5_rootdir']
+        else:
+            self._h5_rootdir = h5_rootdir
+
+        """
+        Check H5 root directory existance
+        """
+        if not path.exists( self._h5_rootdir ):
+            raise MuException( f"No H5 root directory `{self._h5_rootdir}` found.")
+
+        """
+        Set megamicro semaphore
+        """
+        self._megamicro_sem = BoundedSemaphore( value=SRV_MEGAMICRO_MAX_RUN )
+        
+
+
+    def _get_config( self, config_path ):
+        """
+        Look at the congiguration file, if any, and return content
+        """
+        if not path.exists( config_path ):
+            log.info( f" .No configuration file found. Load default config." )
+            return None, {}
+
+        """
+        Read JSON config file
+        """
+        log.info( f" .Found configuration file `{config_path}`" )
+        try:
+            with open( config_path, "r" ) as file:
+                config = json.load( file )
+
+            if not 'jobs' in config:
+                log.info( f" .No scheduler entry found in configuration file: no job(s) to schedule" )
+
+        except Exception as e:
+            log.warning( f"Reading config file failed: {e}. Load default config." )
+            return None, {}
+          
+        return config_path, config
 
-        log.info( f"Starting MegaMicro server at {datetime.fromtimestamp(self._status['start_time']//10**9)}" )
 
 
     def __del__( self ):
@@ -152,9 +227,9 @@ class MegaMicroServer():
         """
         No control for MuH5 if filename is not specified 
         """
-        if self._system == 'MuH5' and self._h5_filename is None:
+        if self._system == 'MuH5' and self._filename is None:
             log.info( 'No H5 file or directory specified: abort system check' )
-            #return
+            return
         
         if self._system == 'MuH5':
             log.info( f"Found H5 files: {mm.h5_files}" )
@@ -182,6 +257,22 @@ class MegaMicroServer():
         self._status['last_error_message'] = ''
 
 
+    async def _schedule_jobs_from_config( self ):
+        """
+        Schedule jobs found in config file 
+        """
+        log.info( f" .Scheduling all jobs found in config file..." )
+        try:
+            if 'jobs' in self._config:
+                jobs: list = self._config['jobs']
+                for job in jobs:
+                    if job['request'] == 'scheduler':
+                        await self.service_scheduler_from_config( job )
+        
+        except Exception as e:
+            log.warning( f"Loading jobs failed: {e}. Stop loading jobs from configuration file")
+
+
     async def run( self, megamicro_system=DEFAULT_MEGAMICRO_SYSTEM, host=DEFAULT_HOST, port=DEFAULT_PORT ):
         """
         Make controls and start server
@@ -215,6 +306,11 @@ class MegaMicroServer():
             log.info( f" .Connection to receiver and running tests: Ok" )
             log.info( f" .MegaMicro system found: '{self._system}'" )
 
+        """
+        Init scheduler with jobs in config file, if any
+        """
+        await self._schedule_jobs_from_config()
+
         """
         All seems ok -> start server and run for ever, waiting for incomming connections
         """
@@ -280,7 +376,7 @@ class MegaMicroServer():
                 elif message['request'] == 'parameters':
                     await self.service_parameters( websocket, cnx_id, message )
                 elif message['request'] == 'scheduler':
-                    await self.service_scheduler( websocket, cnx_id, message )
+                    await self.service_scheduler_from_remote( websocket, cnx_id, message )
                     await websocket.close( reason='Service is done' )
                 elif message['request'] == 'h5handler':
                     await self.service_h5handler( websocket, cnx_id, message )     
@@ -403,7 +499,24 @@ class MegaMicroServer():
                     'response': files
                 }) )
                 log.info( f" .List H5 files directory for {websocket.remote_address[0]}:{websocket.remote_address[1]}" )     
-        
+
+        elif command == '*ls':
+            """
+            List curent files root directory
+            """
+
+            try:
+                files = fnmatch.filter( listdir( self._h5_rootdir ), '*' )
+            except Exception as e:
+                await self.service_h5handler_error( websocket, f"*ls command failed: {e}" )
+            else:
+                await websocket.send( json.dumps( {
+                    'type': 'response',
+                    'response': files
+                }) )
+                log.info( f" .List all files directory for {websocket.remote_address[0]}:{websocket.remote_address[1]}" ) 
+
+
         elif command == 'h5pwd':
             """
             Get current absolute path
@@ -434,11 +547,67 @@ class MegaMicroServer():
             }) )
             log.info( f" .Get H5 default directory for {websocket.remote_address[0]}:{websocket.remote_address[1]}" )   
 
+        elif command == 'h5get':
+            """
+            Send requested file
+            """
+
+            if 'filename' not in parameters:
+                await self.service_h5handler_error( websocket, f"Request failed: filename parameter is missing" )
+                return
+
+            filename = parameters['filename']
+
+            if not path.exists( self._h5_rootdir + '/' + filename ): 
+                await self.service_h5handler_error( websocket, f"Request failed: file {self._h5_rootdir + '/' + filename} does not exist" )
+                return
+            
+            """
+            Thread sending file
+            """
+            try:
+                await self._sendfile( websocket, self._h5_rootdir + '/' + filename )
+            except Exception as e:
+                await self.service_h5handler_error( websocket, f"Request failed: {e}" )
+                return
+
+            log.info( f" .Sent file {self._h5_rootdir + '/' + filename} for {websocket.remote_address[0]}:{websocket.remote_address[1]}" ) 
+
         else:
             await self.service_h5handler_error( websocket, f"Request failed: unknown command `{command}`" )
             return
 
 
+    async def _sendfile( self, websocket, filename ):
+        """
+        Send file on websocket
+        """
+
+        with open( filename, "rb" ) as file:
+            """
+            Send start message to client
+            """
+            await websocket.send( json.dumps( {
+                'type': 'response',
+                'response': 'START',
+                'buffer_sze': DEFAULT_FILESENDING_BUFFER_SIZE
+            }) )
+
+            bytes = file.read( DEFAULT_FILESENDING_BUFFER_SIZE )
+            while bytes:
+                await websocket.send( bytes )
+                bytes = file.read( DEFAULT_FILESENDING_BUFFER_SIZE )
+
+        """
+        Send end message to client
+        """
+        await websocket.send( json.dumps( {
+            'type': 'response',
+            'response': 'STOP'
+        }) )
+
+
+
     async def service_h5handler_error( self, websocket, msg: str ):
         """
         Send error message to client
@@ -524,6 +693,61 @@ class MegaMicroServer():
         
         return False
 
+    def _sched_job_pending_list( self ):
+        """
+        List pending jobs
+
+        :return: array of dictionnaries describing scheduled pending jobs and status 
+        :rtype: list[dict] 
+        """
+        jobs = []
+        for task in self._sched_tasks:
+            start = datetime.fromtimestamp( task['parameters']['sched_start_time'] )
+            stop = datetime.fromtimestamp( task['parameters']['sched_stop_time'] )
+            duration = (stop - start ).total_seconds()
+            if task['status'] == 'pending':
+                jobs.append( {
+                    'task_id': task['task_id'],
+                    'command': task['command'],
+                    'planned start': str( start ),
+                    'planned stop': str( stop ),
+                    'duration': duration,
+                    'parameters': task['parameters'],
+                    'status': task['status'],
+                    'message': task['message'],
+                } )
+
+        return jobs        
+
+
+    def _sched_job_active_list( self ):
+        """
+        List active jobs
+
+        :return: array of dictionnaries describing scheduled active jobs and status 
+        :rtype: list[dict] 
+        """
+        jobs = []
+        for task in self._sched_tasks:
+            start = datetime.fromtimestamp( task['parameters']['sched_start_time'] )
+            stop = datetime.fromtimestamp( task['parameters']['sched_stop_time'] )
+            duration = (stop - start ).total_seconds()
+            if task['status'] == 'active':
+                jobs.append( {
+                    'task_id': task['task_id'],
+                    'command': task['command'],
+                    'planned start': str( start ),
+                    'planned stop': str( stop ),
+                    'duration': duration,
+                    'parameters': task['parameters'],
+                    'status': task['status'],
+                    'message': task['message'],
+                } )
+
+        return jobs     
+
+
+
     def _sched_job_list( self ):
         """
         List all job in the scheduler stack with their status
@@ -574,9 +798,40 @@ class MegaMicroServer():
             return True
 
 
-    async def service_scheduler( self, websocket, cnx_id, message ):
+    async def service_scheduler_from_config( self, job ):
         """
-        Execute a job scheduling request according message content. 
+        Schedule tasks from the configuration file
+        """
+        if not 'parameters' in job:
+            raise MuException( f"Error in config file: no parameters entry" )
+
+        """
+        Convert isoformatted date to timestamp
+        """
+        parameters = job['parameters']
+        if not 'sched_start_time' in parameters:
+            raise MuException( f"Error in config file: no `sched_start_time` entry" )
+        else:
+            job['parameters']['sched_start_time'] = datetime.timestamp( datetime.fromisoformat( parameters['sched_start_time'] ) )
+
+        if not 'sched_stop_time' in parameters:
+            raise MuException( f"Error in config file: no `sched_stop_time` entry" )
+        else:
+            job['parameters']['sched_stop_time'] = datetime.timestamp( datetime.fromisoformat( parameters['sched_stop_time'] ) )
+
+        await self.service_scheduler( job )
+
+
+    async def service_scheduler_from_remote( self, websocket, cnx_id, message ):
+        """
+        Schedule tasks from user client requests
+        """
+        await self.service_scheduler( message, websocket, cnx_id )
+
+
+    async def service_scheduler( self, message, websocket=None, cnx_id=None ):
+        """
+        Process a job scheduling request according message content. 
         Task timing is controled such as to prevent from conflicts with other scheduled tasks.
 
         * On error: send an error response message to client, then leave
@@ -592,13 +847,17 @@ class MegaMicroServer():
                 'request': 'scheduler',         # the client request
                 'parameters': {                 # dicttionary of task parameters
                     'command': str              # the command to schedule
-                    'sched_start_time': int     # timestamp indicating the exact starting time
-                    'sched_stop_time': int      # timestamp indicating the time to stoip the task
+                    'sched_start_time': float   # timestamp indicating the exact starting time
+                    'sched_stop_time': float    # timestamp indicating the time to stoip the task
                     ...                         # MegaMicro usual parameters or others
                 }
             }
         """
-        log.info( f" .Handle scheduling request for {websocket.remote_address[0]}:{websocket.remote_address[1]} remote client" )
+
+        if websocket==None:
+            log.info( f" .Handle scheduling request from configuration file" )
+        else:
+            log.info( f" .Handle scheduling request for {websocket.remote_address[0]}:{websocket.remote_address[1]} remote client" )
 
         """
         Perform controls.
@@ -607,6 +866,7 @@ class MegaMicroServer():
         if 'parameters' not in message:
             await self.service_scheduler_error( websocket, 'Bad request with missing parameters' )
             return
+
         parameters = message['parameters']
 
         if 'command' not in parameters:
@@ -631,12 +891,26 @@ class MegaMicroServer():
                     await self.service_scheduler_error( websocket, 'Bad request with missing `sched_start_time` or `sched_stop_time` timestamp parameters' )
                     return
 
-                start =  parameters['sched_start_time']
-                stop =  parameters['sched_stop_time']
+                start: float =  parameters['sched_start_time']
+                stop: float =  parameters['sched_stop_time']
+                now: float = datetime.now().timestamp()
+
                 if stop <= start:
                     await self.service_scheduler_error( websocket, 'Bad request with incoherent start and stop timestamps' )
                     return
 
+                print( 'parameters=', parameters )
+
+
+                if start < now:
+                    """
+                    Job is late. Try to report
+                    """
+                    stop = stop - start + now
+                    start = now
+                    parameters['sched_start_time'] = start
+                    parameters['sched_stop_time'] = stop
+
                 """
                 Look for possible conflicts with pending and active tasks
                 """
@@ -647,7 +921,7 @@ class MegaMicroServer():
                 """
                 Schedule the task
                 """
-                task = Timer( 2, self.service_scheduler_handler, kwargs=parameters )
+                task = Timer( start - now, self.service_scheduler_handler, kwargs=parameters )
                 task.start()
                 log.info( f" .task {command} scheduled at time {start}" )
                 self._sched_tasks.append( {
@@ -663,12 +937,89 @@ class MegaMicroServer():
                 """
                 Sends aknowledgement to client
                 """
-                await websocket.send( json.dumps( {
-                    'type': 'response',
-                    'response': 'OK',
-                    'message': 'successfull request'
-                }) )
-                log.info( f" .Scheduled task for {websocket.remote_address[0]}:{websocket.remote_address[1]}" )
+                if websocket != None:
+                    await websocket.send( json.dumps( {
+                        'type': 'response',
+                        'response': 'OK',
+                        'message': 'successfull request'
+                    }) )
+                    log.info( f" .Scheduled task for {websocket.remote_address[0]}:{websocket.remote_address[1]}" )
+                else:
+                    log.info( f" .Scheduled task from config file: successfull request" )
+
+
+            elif command == 'prun':
+                """
+                Permanent run cammand
+                """
+                parameters['task_id'] = self._sched_next_id
+
+                """
+                Look for possible conflicts with pending and active tasks
+                """
+                if len( self._sched_job_pending_list() ) > 0 or len( self._sched_job_active_list() ) > 0:
+                    await self.service_scheduler_error( websocket, 'Cannot schedule permanent task: there are active or pending jobs' )
+                    return                    
+
+                if 'sched_start_time' not in parameters or 'sched_stop_time' not in parameters:
+                    await self.service_scheduler_error( websocket, 'Bad request with missing `sched_start_time` or `sched_stop_time` timestamp parameters' )
+                    print( 'parameters=', parameters )
+                    return
+
+                if 'sched_repeat_time' not in parameters:
+                    await self.service_scheduler_error( websocket, 'Bad request with missing `sched_repeat_time` parameter' )
+                    return
+
+                start: float =  parameters['sched_start_time']
+                stop: float =  parameters['sched_stop_time']
+                repeat: float = parameters['sched_repeat_time']
+
+                if stop <= start:
+                    await self.service_scheduler_error( websocket, 'Bad request with incoherent start and stop timestamps' )
+                    return
+
+                if ( datetime.fromtimestamp( stop ) - datetime.fromtimestamp( start ) ).total_seconds() > repeat:
+                    await self.service_scheduler_error( websocket, f"Bad request: duration job ({(datetime.fromtimestamp( stop ) - datetime.fromtimestamp( start ) ).total_seconds()})s is greater than repeat time duration ({repeat}s)" )
+                    return
+
+                now: float = datetime.now().timestamp()
+                if start < now:
+                    """
+                    Job is late. Try to report
+                    """
+                    stop = stop - start + now
+                    start = now
+                    parameters['sched_start_time'] = start
+                    parameters['sched_stop_time'] = stop
+
+                """
+                Schedule the task
+                """
+                task = threading.Thread( target = self.service_scheduler_handler, kwargs=parameters )
+                task.start()
+                log.info( f" .task {command} permanently scheduled at time {start} with repitition delay {repeat}" )
+                self._sched_tasks.append( {
+                    'task_id': self._sched_next_id,
+                    'task': task,
+                    'command': command,
+                    'parameters':parameters,
+                    'status': 'pending',
+                    'message': ''
+                } ) 
+                self._sched_next_id += 1
+
+                """
+                Sends aknowledgement to client
+                """
+                if websocket != None:
+                    await websocket.send( json.dumps( {
+                        'type': 'response',
+                        'response': 'OK',
+                        'message': 'successfull request'
+                    }) )
+                    log.info( f" .Scheduled task for {websocket.remote_address[0]}:{websocket.remote_address[1]}" )
+                else:
+                    log.info( f" .Scheduled task from config file: successfull request" )
 
             elif command == 'lsjob':
                 """
@@ -677,11 +1028,16 @@ class MegaMicroServer():
 
                 jobs = self._sched_job_list()
 
-                await websocket.send( json.dumps( {
-                    'type': 'response',
-                    'response': jobs
-                }) )
-                log.info( f" .Sent scheduler job list for {websocket.remote_address[0]}:{websocket.remote_address[1]}" )           
+                if websocket != None:
+                    await websocket.send( json.dumps( {
+                        'type': 'response',
+                        'response': jobs
+                    }) )
+                    log.info( f" .Sent scheduler job list for {websocket.remote_address[0]}:{websocket.remote_address[1]}" )           
+                else:
+                    log.info( f" .Scheduler job list from config file: successfull request" )
+                    print( "Scheduler job list from config file request:")
+                    print( jobs )
 
 
             elif command == 'rmjob':
@@ -705,11 +1061,14 @@ class MegaMicroServer():
                     await self.service_scheduler_error( websocket, f"Failed to remove job {task_id}: unknown error" )
                     return
                 else:
-                    await websocket.send( json.dumps( {
-                        'type': 'response',
-                        'response': 'OK'
-                    }) )
-                    log.info( f" .Removed job id [{task_id}] from scheduler stack for {websocket.remote_address[0]}:{websocket.remote_address[1]}" )
+                    if websocket != None:
+                        await websocket.send( json.dumps( {
+                            'type': 'response',
+                            'response': 'OK'
+                        }) )
+                        log.info( f" .Removed job id [{task_id}] from scheduler stack for {websocket.remote_address[0]}:{websocket.remote_address[1]}" )
+                    else:
+                        log.info( f" .Removed job id [{task_id}] from scheduler stack for config file request" )
 
             else:
                 await self.service_scheduler_error( websocket, f"Bad request with unknown command `{command}`" )
@@ -730,12 +1089,58 @@ class MegaMicroServer():
         This is a standalone execution provided the MegaMicro receiver is free 
         """
         command = kwargs.get( 'command' )
-        log.info( f" .executing task {command} at ..." )
- 
+        task_id = kwargs.get( 'task_id' ) 
+
         if command == 'run':
+            log.info( f" .executing task {command} at {datetime.now()}" )
+            self._sched_set_status( task_id, 'active' )
             self.service_scheduler_handler_run( parameters=kwargs )
+            if self._sched_get_status( task_id ) != 'error':
+                self._sched_set_status( task_id, 'completed' )
+
+        elif command == 'prun':
+            start: float =  kwargs['sched_start_time']
+            stop: float =  kwargs['sched_stop_time']
+            repeat: float = kwargs['sched_repeat_time']
+            duration: float = stop - start
+            self._sched_set_status( task_id, 'active' )
+
+            counter: int = 0
+            counter_abort: int = 0
+            while True:
+                now: float = datetime.now().timestamp()
+                if start <= now:
+                    """
+                    Execute current
+                    """
+                    kwargs['sched_start_time'] = now
+                    kwargs['sched_stop_time'] = now + duration
+                    log.info( f" .executing task {command} at {datetime.now()}, next will start at {datetime.fromtimestamp( now + repeat )}" )
+                    self.service_scheduler_handler_run( parameters=kwargs )
+                    if self._sched_get_status( task_id ) == 'error':
+                        counter_abort += 1
+                        log.info( f" .Attempt new execution of task [{task_id}] (x {counter_abort} times)" )
+                        if counter_abort > DEFAULT_MAX_ERROR_SCHED_COUNTER:
+                            """
+                            Abort job if error count grow up
+                            """
+                            log.info( f" .Abort scheduled task [{task_id}] after {counter_abort} attempts" )
+                            break
+                    elif counter_abort > 0:
+                        counter_abort = 0
+
+                    """
+                    Schedule next
+                    """
+                    start = now + repeat
+                    stop = now + duration + repeat
+                    counter += 1
+                else:
+                    sleep( start - now )
+
+            log.info( f" .end of task {command} executing at {datetime.now()}" )
+
 
-        
 
     def service_scheduler_handler_run( self, parameters ):
         """
@@ -793,13 +1198,16 @@ class MegaMicroServer():
         """
         Send an error message to client
         """
-        await websocket.send( json.dumps( {
-            'type': 'error',
-            'response': 'NOT OK',
-            'error': 'Unable to serve scheduling request',
-            'message': msg
-        }) )
-        log.info( f" .Could not serve scheduling request for {websocket.remote_address[0]}:{websocket.remote_address[1]}: {msg}" )
+        if websocket==None:
+            log.warning( f"Unable to serve scheduling request: {msg}" )
+        else:
+            await websocket.send( json.dumps( {
+                'type': 'error',
+                'response': 'NOT OK',
+                'error': 'Unable to serve scheduling request',
+                'message': msg
+            }) )
+            log.info( f" .Could not serve scheduling request for {websocket.remote_address[0]}:{websocket.remote_address[1]}: {msg}" )
 
 
     async def service_bfdoa( self, websocket, cnx_id, message ):
@@ -1184,12 +1592,13 @@ async def main():
     parser.add_argument( "-s", "--system", help=f"set the MegaMicro receiver type system (Mu32, Mu256, Mu1024, MuH5). Default is {DEFAULT_MEGAMICRO_SYSTEM}" )
     parser.add_argument( "-c", "--maxconnect", help=f"set the server maximum simultaneous connections. Default is {DEFAULT_MAX_CONNECTIONS}" )
     parser.add_argument( "-f", "--file", help=f"set the server in H5 file reader mode on specified file or directory. Default is None" )
+
     args = parser.parse_args()
     host = DEFAULT_HOST
     port = DEFAULT_PORT
     megamicro_system = DEFAULT_MEGAMICRO_SYSTEM
     maxconnect = DEFAULT_MAX_CONNECTIONS
-    filename = None
+    file = None
     if args.host:
         host = args.host
     if args.port:
