@@ -28,6 +28,39 @@ See documentation on usb websocket python programming on https://websockets.read
 Please, note that the following packages should be installed before using this program:
 	> pip install websockets
 """
+"""
+see getting file on https://stackoverflow.com/questions/9382045/send-a-file-through-sockets-in-python
+
+client code:
+
+import socket
+import time
+
+TCP_IP = 'localhost'
+TCP_PORT = 9001
+BUFFER_SIZE = 1024
+
+s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+s.connect((TCP_IP, TCP_PORT))
+recived_f = 'imgt_thread'+str(time.time()).split('.')[0]+'.jpeg'
+with open(recived_f, 'wb') as f:
+    print('file opened')
+    while True:
+        #print('receiving data...')
+        data = s.recv(BUFFER_SIZE)
+        print('data=%s', (data))
+        if not data:
+            f.close()
+            print('file close()')
+            break
+        # write data to a file
+        f.write(data)
+
+print('Successfully get the file')
+s.close()
+print('connection closed')
+"""
+
 
 import time
 import threading
@@ -116,23 +149,100 @@ class MegaMicroWS( MegaMicro ):
 		Send a H5 file manager command to server
 		"""
 		try:
-			async with websockets.connect( 'ws://' + self._server_address + ':' + str( self._server_port ) ) as websocket:
-				request = json.dumps( {
-					'request': 'h5handler',
-					'parameters': self.__h5_parameters
-				} )
-				await websocket.send( request )
-				self.__server_response = json.loads( await websocket.recv() )
+			if self.__h5_parameters['command'] == 'h5get':
+				"""
+				Getting file require special transaction with server
+				"""
+				async with websockets.connect( 'ws://' + self._server_address + ':' + str( self._server_port ) ) as websocket:
+					"""
+					Send the request
+					"""
+					await websocket.send( json.dumps( {
+						'request': 'h5handler',
+						'parameters': self.__h5_parameters
+					} ) )
+					response = json.loads( await websocket.recv() )
+					
+					if response['type'] == 'response' and response['response'] == 'START':
+						"""
+						get file
+						"""
+						with open( self.__h5_parameters['filename'], 'wb') as file:
+							while True:
+								data = await websocket.recv()
+								if isinstance( data, str ):
+									"""
+									No more data to upload: end of transfert
+									"""
+									response = json.loads( data )
+									if response['type'] == 'response' and response['response'] == 'STOP':
+										"""
+										No more data to upload: end of transfert
+										"""
+										#websocket.close()
+										self.__server_response = response
+										break
+									else:
+										"""
+										Unespected response from server
+										"""
+										#websocket.close()
+										self.__server_response = {
+											'type': 'error',
+											'error': 'Unespected response from server',
+											'message': f"Type response was {response['type']}. Local file may be corrupted",
+											'response': response['response']
+										}
+										log.warning( f"Unespected response from server" )
+										break
+								else:
+									file.write( data )
 
-		except websockets.ConnectionClosedOK:
-			log.info( f" .Connexion closed by peer" )
+					elif response['type'] == 'error':
+						self.__server_response = response
+						log.warning( f"Request failed with error response from server" )
+					else:
+						self.__server_response = response
+						log.warning( f"Request failed with unespected response from serveur (type={response['type']}, response={response['response']})" )
+			else:
+				"""
+				More conventional commands
+				"""
+				async with websockets.connect( 'ws://' + self._server_address + ':' + str( self._server_port ) ) as websocket:
+					request = json.dumps( {
+						'request': 'h5handler',
+						'parameters': self.__h5_parameters
+					} )
+					await websocket.send( request )
+					self.__server_response = json.loads( await websocket.recv() )
+
+		except websockets.ConnectionClosedOK as e:
+			self.__server_response = {
+				'type': 'response',
+				'error': 'Connexion closed by server (Unexpected)',
+				'message': f"{e}",
+				'response': ''
+			}
+			log.warning( f" .Connexion closed by peer" )
 		except websockets.ConnectionClosedError as e:
-			log.info( f" .Connexion closed by peer with error: {e}" )
+			self.__server_response = {
+				'type': 'error',
+				'error': 'Connexion closed by server',
+				'message': e,
+				'response': ''
+			}			
+			log.warning( f" .Connexion closed by server with error: {e}" )
 		except Exception as e:
-			raise e
+			self.__server_response = {
+				'type': 'error',
+				'error': 'Unknown error',
+				'message': e,
+				'response': ''
+			}			
+			log.warning( f" .Getfile request failed: {e}" )			
 
 
-	def scheduler( self, command, start_datetime: datetime=None, stop_datetime: datetime=None, parameters=None ):
+	def scheduler( self, command, start_datetime: datetime=None, stop_datetime: datetime=None, repeat_delay=None, parameters=None ):
 		"""
 		The scheduler send jobs to be scheduled by the remote server.
 		Note that the scheduling activity is not handled by the client but only by the server.
@@ -144,6 +254,8 @@ class MegaMicroWS( MegaMicro ):
 		:type start_datetime: datetime
 		:param stop_datetime: Optionnal task stop time. Default defined for one second duration
 		:type start_datetime: datetime
+		:param repeat_delay: Optionnal task repeting delay. Default defined for two seconds
+		:type repeat_delay: float
 		:param parameters: MegaMicro parameters
 		:type parameters: dict
 		:return: the object
@@ -152,9 +264,11 @@ class MegaMicroWS( MegaMicro ):
 		if command == 'run':
 			log.info( f"Scheduling run command..." )
 			self.__server_response = 'OK'
+			
 			if start_datetime is None:
 				start_datetime = datetime.now()
 			start_timestamp = start_datetime.timestamp()
+
 			if stop_datetime is None:
 				stop_timestamp = start_timestamp + timedelta( seconds=1 )
 			else:
@@ -175,6 +289,40 @@ class MegaMicroWS( MegaMicro ):
 			self.__sched_parameters = parameters
 			asyncio.run( self.scheduler_send() )
 
+		elif command == 'prun':
+			log.info( f"Scheduling permnanent run command..." )
+			self.__server_response = 'OK'
+			
+			if start_datetime is None:
+				start_datetime = datetime.now()
+			start_timestamp = start_datetime.timestamp()
+
+			if stop_datetime is None:
+				stop_timestamp = start_timestamp + timedelta( seconds=1 )
+			else:
+				stop_timestamp = stop_datetime.timestamp()
+
+			if repeat_delay == None:
+				repeat_delay = 2
+
+			if parameters is None:
+				parameters = {
+					'sampling_frequency': DEFAULT_SAMPLING_FREQUENCY,
+					'mems': DEFAULT_ACTIVATED_MEMS
+				}
+
+			parameters.update( {
+				'command': command,
+				'sched_start_time':  start_timestamp,
+				'sched_stop_time':  stop_timestamp,
+				'sched_repeat_time': repeat_delay
+			} )
+
+			self.__sched_parameters = parameters
+			asyncio.run( self.scheduler_send() )
+
+
+
 		else:
 			log.info( f"Send {command} command to server scheduler..." )
 
