@@ -49,7 +49,7 @@ mu32log.setLevel( logging.INFO )
 """
 Power signal queue
 """
-signal_q = queue.Queue()
+power_q = queue.Queue()
 
 
 def main():
@@ -65,51 +65,40 @@ def main():
 			post_callback_fn=my_process_function, 		# the user defined data processing function
 			callback_fn=my_callback_fn
 		)
-	except:
-		print( 'aborting' )
+	except Exception as e:
+		print( 'aborting: ', e )
 
 
 def my_callback_fn( mu32: Mu32, data ):
 	"""
 	Compute energy (mean power) on transfered frame and push it in the queue
-	"""
-	signal = data.reshape( mu32.buffer_length, mu32.mems_number )
-	signal = np.float32( signal )
-	mean_power = np.sum( signal**2, axis=0 ) / mu32.buffer_length
+	"""	
+	signal = data * mu32.sensibility
+	mean_power = np.sum( signal**2, axis=1 ) / mu32.buffer_length
 
-	signal_q.put( mean_power )
+	power_q.put( mean_power )
 
 
 def my_process_function( mu32: Mu32 ):
-	"""
-	The data processing function is called  after the acquisition process has finished.
-	Plot signal mean power comming from activated MEMs 
-	"""
-
-	q_size = signal_q.qsize()
-	if q_size== 0:
-		raise Exception( 'No received data !' )
-
-	print( 'got %d transfer buffers from %d microphones (recording time is: %f s)' % (q_size, mu32.mems_number, q_size*mu32.buffer_length/mu32.sampling_frequency) )	
 
 	"""
 	get queued signals from Mu32
 	"""
-	signal = []
-	for _ in range( q_size ):
-		signal = np.append( signal, signal_q.get( block=False ) )
-
-	signal = signal.reshape( q_size, mu32.mems_number )
+	q_size = power_q.qsize()
+	power = power_q.get()
+	while not power_q.empty():
+		power = np.append( power, power_q.get() )
+	power = np.reshape( power, (q_size, mu32.mems_number) ).T
 
 	"""
 	plot mems signals 
 	"""
 	fig, axs = plt.subplots( mu32.mems_number )
 	fig.suptitle('Mems energy')
-	time = np.array( [t for t in range( q_size )] ) * mu32.buffer_length / mu32.sampling_frequency
+	time = np.array( range( np.size(power,1) ) ) / mu32.sampling_frequency
+	
 	for s in range( mu32.mems_number ):
-		X = signal[:,s]
-		axs[s].plot( time, X )
+		axs[s].plot( time, power[s,:] )
 		axs[s].set( xlabel='time in seconds', ylabel='mic %d' % s )
 
 	plt.show()
