@@ -25,6 +25,19 @@
 Mu32 documentation is available on https://distalsense.io
 """
 
+class MuException( Exception ):
+	value = None
+
+	def __init__( self, value=None ):
+		Exception.__init__( self )
+		if value is not None:
+			self.value = value
+
+	def __str__(self):
+		return '%s [%s]' % ( 'MuException: ', self.value )
+
+
+
 class Mu32Exception( Exception ):
 	value = None
 
